summary.hbal: Summarizing from an hbal Object
Description
This function prints a summary from an hbal Object.
Usage
# S3 method for hbal
summary(object, print.level = 0, ...)
Arguments
- object
an object of class hbalobject as returned by hbal.
- print.level
details of printed output: 0 for minimum, 1 for detailed.
- ...
Further arguments to be passed to summary.hbal().
Author
Yiqing Xu, Eddie Yang